@@ -51,9 +51,8 @@ import php.java.bridge.http.IContextFactory;
  * This class implements the ScriptEngine.<p>
  *@see php.java.script.InvocablePhpScriptEngine
  *@see php.java.script.PhpScriptEngine
- *@author jostb
  */
-abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
+public abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
 
 	
     /**
@@ -61,7 +60,6 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
      */
     protected PhpProcedureProxy script = null;
     protected Object scriptClosure = null;
-    protected ScriptException scriptException = null;
     protected String name = null;
     
     /**
@@ -70,7 +68,7 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
     protected HttpProxy continuation = null;
     protected final HashMap processEnvironment = getProcessEnvironment();
     protected Map env = null;
-    IContextFactory ctx = null;
+    protected IContextFactory ctx = null;
     
     private ScriptEngineFactory factory = null;
 
@@ -145,11 +143,6 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
         this.factory = factory;
     }
 
-    /* Revert constructor chain. Call super(false); privateInit(); super.initialize(), 
-     * see PhpFacesScriptEngine constructor and PhpScriptEngine() constructor. -- The jsr223 API is really odd ... */
-    protected SimplePhpScriptEngine(boolean initialize) {
-        if(initialize) initialize();
-    }
     protected void setName(String name) {
         int length = name.length();
         if(length>160) length=160;
@@ -170,6 +163,7 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
 	/* send the session context now, otherwise the client has to 
 	 * call handleRedirectConnection */
 	env.put("X_JAVABRIDGE_CONTEXT", ctx.getId());
+	
 	/* the client should connect back to us */
 	StringBuffer buf = new StringBuffer("h:");
 	buf.append(Util.getHostAddress());
@@ -190,7 +184,7 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
     
             try { doEval(reader, context); } catch (Exception e) {
         	Util.printStackTrace(e);
-        	throw this.scriptException = new PhpScriptException("Could not evaluate script", e);
+        	throw new PhpScriptException("Could not evaluate script", e);
             }
         } finally {
             release();
@@ -300,21 +294,21 @@ abstract class SimplePhpScriptEngine extends AbstractScriptEngine {
 
     /**
      * Release the continuation
- * @throws InterruptedException 
      */
     public void release() {
 	if(continuation != null) {
 	    try {
 		continuation.release();
-	        ctx.waitFor();
+		ctx.waitForInitializedContext();
 	    } catch (InterruptedException e) {
 		    return;
 	    }
-	    ctx.removeOrphaned(); ctx = null;
+	    ctx.release(); 
+	    ctx = null;
+	    
 	    continuation = null;
 	    script = null;
 	    scriptClosure = null;
-	    scriptException = null;
 	}
     }
 
